@@ -314,19 +314,22 @@ sub unique_message_for_constraint {
 
 sub _id_clause {
     my ( $resultset, $id ) = @_;
+
     my @pks = $resultset->result_source->primary_columns;
-    my @ids;
-    if ( ref $id eq 'ARRAY' ) {
-        @ids = @$id;
+    my %clause;
+    # multiple primary key
+    if ( scalar @pks > 1 ) {
+        die "multiple primary key invalid" if ref $id ne 'ARRAY';
+        my $cond = $id->[0];
+        my @phrase;
+        foreach my $col ( keys %$cond ) {
+            $clause{$col} = { '!=' => $cond->{$col} };
+        }
     }
     else {
-        @ids = ($id);
+        %clause = ( $pks[0] => { '!=' => $id } );
     }
-    my %result;
-    for my $i ($#ids) {
-        $result{ $pks[$i] } = { '!=' => $ids[$i] };
-    }
-    return %result;
+    return %clause;
 }
 
 sub build_item {
@@ -422,7 +425,7 @@ HTML::FormHandler::TraitFor::Model::DBIC - model role that interfaces with DBIx:
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
@@ -640,7 +643,7 @@ FormHandler Contributors - see HTML::FormHandler
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Gerda Shank.
+This software is copyright (c) 2013 by Gerda Shank.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
